import lpsolve.*;

public class LPDemo {
  public static void main(String[] args) {
    try {
      // maak een Linear Programma voor 2 variabelen x1, x2
      int aantalVariabelen = 2;
      LpSolve lpProblem = LpSolve.makeLp(0, aantalVariabelen);
      lpProblem.setLpName("Demo");
      // x1 is reeel en x1 >= 0.5
      lpProblem.setColName(1, "x1");
      lpProblem.setLowbo(1, 0.5);
      // x2 is geheel en x2 >= 0 (dit is de default)
      lpProblem.setColName(2, "x2");
      lpProblem.setInt(2, true);
      // algemene coefficienten array
      double[] row = new double[aantalVariabelen+1];
      //objectief functie: maximaliseer x1 + 2*x2
      row[1] = 1.0; row[2] = 2.0;
      lpProblem.setObjFn(row);
      lpProblem.setMaxim();
      // randvoorwaarde A: 3*x1 + x2 <= 9
      row[1] = 3.0; row[2] = 1.0;
      lpProblem.addConstraint(row, LpSolve.LE, 9.0);
      lpProblem.setRowName(lpProblem.getNrows(), "A");
      // randvoorwaarde B: x1 + 4*x2 <= 12
      row[1] = 1.0; row[2] = 4.0;
      lpProblem.addConstraint(row, LpSolve.LE, 12.0);
      lpProblem.setRowName(lpProblem.getNrows(), "B");
      // toon het huidig probleem
      lpProblem.printLp();
      // beperk de feedback tijdens het oplossen tot de belangrijkste informatie
      lpProblem.setVerbose(LpSolve.IMPORTANT);
      // los het Lineair programma op
      int ret = lpProblem.solve();
      if (ret == LpSolve.OPTIMAL) {
        System.out.println("Optimum is gevonden");
        // toon de waarde van de objectief functie
        System.out.println("Objectief functie: " + lpProblem.getObjective());
        // toon de waarde van de beslissingsvariabelen
        lpProblem.getVariables(row);
        for(int j = 0; j < aantalVariabelen; j++) {
          System.out.println(lpProblem.getColName(j + 1) + ": " + row[j]);
        }
      } else {
        System.out.println("Geen optimum gevonden");
      }
      // verwijder het LP probleem en geef het gebruikte geheugen vrij
      lpProblem.deleteLp();
    }
    catch (LpSolveException e) {
      e.printStackTrace();
    }
  }
}
